<#if isPolled == true>
/**
 * TIMER Switch Frequency - Polling Example Driver File
 * 
 <#if isTestMode == true>
 * @file uc2.c
 *
 * @addtogroup timer-switch-frequency-example TIMER Switch Frequency
 <#else>
 * @file timer_example.c
 * 
 * @addtogroup timer_example
  </#if>
 * 
 * @brief This is the generated example implementation for TIMER Switch Frequency - Polled driver.
 *
 * @version TIMER Switch Frequency - Polled Example Version 1.0.0
*/
<#elseif isCallback == true>
/**
 * TIMER Switch Frequency - Callback Example Driver File
 * 
 <#if isTestMode == true>
 * @file uc2.c
 *
 * @addtogroup timer-switch-frequency-example TIMER Switch Frequency
 <#else>
 * @file timer_example.c
 </#if>
 * 
 * @addtogroup timer_example
 * 
 * @brief This is the generated example implementation for TIMER Switch Frequency - Callback driver.
 *
 * @version TIMER Switch Frequency - Callback Example Version 1.0.0
*/
</#if>
${disclaimer}

<#if isPolled == true>
/* Use Case 2 - Polled implementation. Copy this code to your project source, e.g., to main.c  */
<#elseif isCallback == true>
/* Use Case 2 - Callback implementation. Copy this code to your project source, e.g., to main.c  */
</#if>
<#if isTestMode == false>
/* ------------------------------------------------------------------
</#if>

<#if isTestMode == true>
#include "../../system/system.h"
#include "uc2.h"

static void Timer_Callback(void);
static void Button_Callback(void);
static void Timer_ChangeFrequency(void);

static const struct TMR_INTERFACE *Timer = &TIMERX;
static volatile bool changePeriod = false;
static volatile bool buttonPressed = false;

<#else>
#include "mcc_generated_files/system/system.h"

static void Timer_Callback(void);
static void Button_Callback(void);
static void Timer_ChangeFrequency(void);

static const struct TMR_INTERFACE *Timer = &Timer0; // TODO: Replace Timer0 with name of const struct TMR_INTERFACE, from MCC Generated Files > timer > tmrx.c
static volatile bool changePeriod = false;
static volatile bool buttonPressed = false;

</#if>
// 8-bit Timer example values: Timer Mode: 8-bit, Clock Prescaler 1:64, Clock Source: LFINTOSC
#define LED_100MS (0x2F) // If different settings, for correct value, set period to 0.1 (100ms), Generate Code, replace with value of TMRxH, in TMRx_Initialize
#define LED_500MS (0xF1) // If different settings, for correct value, set period to 0.5 (500ms), Generate Code, replace with value of TMRxH, in TMRx_Initialize

// 16-bit Timer example values: Timer Mode: 16-bit, Clock Source: LFINTOSC
//#define LED_100MS (0xF3E4) // If different settings, for correct value, set period to 0.1 (100ms), Generate Code, replace with value of TMRxH:TMRxL, in TMRx_Initialize
//#define LED_500MS (0xC374) // If different settings, for correct value, set period to 0.5 (500ms), Generate Code, replace with value of TMRxH:TMRxL, in TMRx_Initialize

static void Timer_Callback(void)
{
    IO_LED_Toggle();
    IO_Debug_Toggle();

}

static void Button_Callback(void)
{
    if (!buttonPressed)
    {
        buttonPressed = true;
        changePeriod = true;
    }
}

static void Timer_ChangeFrequency(void)
{
    static volatile bool period100ms = false; // Set initial period to 500ms

    Timer->Stop();
    if (period100ms)
    {
<#if isTestMode == true>
        TMR0 = 0x0; // Restart the timer
<#else>
        TMRx_Write(0); // Restart the timer, TODO: Replace X with timer
</#if>
        Timer->PeriodCountSet(LED_100MS);
        period100ms = false;
    }
    else
    {
<#if isTestMode == true>
        TMR0 = 0x0; // Restart the timer
<#else>
        TMRx_Write(0); // Restart the timer, TODO: Replace X with timer
</#if>
        Timer->PeriodCountSet(LED_500MS);
        period100ms = true;
    }
    Timer->Start();
}

<#if isPolled == true>
<#if isTestMode == true>
void TIMER_Example2(void)
<#else>
int main(void)
</#if>
{
    SYSTEM_Initialize();
    Timer->TimeoutCallbackRegister(Timer_Callback);
    IO_BUTTON_SetInterruptHandler(Button_Callback); // Select for BUTTON pin you are using
<#if InterfaceType == "Interface_PIC18">
    INTERRUPT_GlobalInterruptEnable();
<#elseif InterfaceType == "Interface_PIC16">
    INTERRUPT_GlobalInterruptEnable();
    INTERRUPT_PeripheralInterruptEnable();
</#if>

    while (1)
    {
        Timer->Tasks();
        if (changePeriod)
        {
            Timer_ChangeFrequency();
            changePeriod = false;
        }

        // Reset button pressed flag after debounce period
        if (buttonPressed && IO_BUTTON_GetValue())
        {
            buttonPressed = false;
        }
    }
}
<#elseif isCallback == true>
<#if isTestMode == true>
void TIMER_Example2(void)
<#else>
int main(void)
</#if>
{
    SYSTEM_Initialize();
    Timer->TimeoutCallbackRegister(Timer_Callback);
    IO_BUTTON_SetInterruptHandler(Button_Callback); // Select for BUTTON pin you are using
<#if InterfaceType == "Interface_PIC18">
    INTERRUPT_GlobalInterruptEnable();
<#elseif InterfaceType == "Interface_PIC16">
    INTERRUPT_GlobalInterruptEnable();
    INTERRUPT_PeripheralInterruptEnable();
</#if>

    while (1)
    {
        if (changePeriod)
        {
            Timer_ChangeFrequency();
            changePeriod = false;
        }

        // Reset button pressed flag after debounce period
        if (buttonPressed && IO_BUTTON_GetValue())
        {
            buttonPressed = false;
        }
    }
}
</#if>
<#if isTestMode == false>
------------------------------------------------------------------ */
</#if>
/**
 End of File
*/